Modules
=======

Sage provides modules of various kinds over various base rings.

.. toctree::
   :maxdepth: 1

   sage/modules/tutorial_free_modules


Free modules, submodules, and quotients
---------------------------------------

.. toctree::
   :maxdepth: 1

   sage/modules/module
   sage/modules/free_module
   sage/modules/free_module_element
   sage/modules/submodule
   sage/modules/quotient_module

See also :mod:`sage.tensor.modules.finite_rank_free_module`.

Modules with basis
------------------

.. toctree::
   :maxdepth: 1

   sage/modules/with_basis/all
   sage/modules/with_basis/cell_module
   sage/modules/with_basis/indexed_element
   sage/modules/with_basis/invariant
   sage/modules/with_basis/morphism
   sage/modules/with_basis/subquotient
   sage/modules/with_basis/representation

Finitely generated modules over a PID
-------------------------------------

.. toctree::
   :maxdepth: 1

   sage/modules/fg_pid/fgp_module
   sage/modules/fg_pid/fgp_element
   sage/modules/fg_pid/fgp_morphism

Finitely presented graded modules
---------------------------------

.. toctree::
   :maxdepth: 1

   sage/modules/fp_graded/free_module
   sage/modules/fp_graded/free_element
   sage/modules/fp_graded/free_morphism
   sage/modules/fp_graded/free_homspace
   sage/modules/fp_graded/module
   sage/modules/fp_graded/element
   sage/modules/fp_graded/morphism
   sage/modules/fp_graded/homspace

   sage/modules/fp_graded/steenrod/module
   sage/modules/fp_graded/steenrod/morphism

Special modules
---------------

.. toctree::
   :maxdepth: 1

   sage/modules/free_module_integer
   sage/modules/free_quadratic_module
   sage/modules/free_quadratic_module_integer_symmetric
   sage/modules/torsion_quadratic_module
   sage/modules/filtered_vector_space
   sage/modules/multi_filtered_vector_space

Morphisms
---------

.. toctree::
   :maxdepth: 1

   sage/modules/vector_space_homspace
   sage/modules/vector_space_morphism

   sage/modules/free_module_homspace
   sage/modules/free_module_morphism

   sage/modules/matrix_morphism

Vectors
-------

.. toctree::
   :maxdepth: 1

   sage/modules/vector_integer_dense
   sage/modules/vector_integer_sparse
   sage/modules/vector_mod2_dense
   sage/modules/vector_modn_dense
   sage/modules/vector_modn_sparse
   sage/modules/vector_rational_dense
   sage/modules/vector_rational_sparse
   sage/modules/vector_symbolic_dense
   sage/modules/vector_symbolic_sparse
   sage/modules/vector_callable_symbolic_dense
   sage/modules/vector_double_dense
   sage/modules/vector_real_double_dense
   sage/modules/vector_numpy_dense
   sage/modules/vector_numpy_integer_dense
   sage/modules/vector_complex_double_dense
   sage/modules/complex_double_vector
   sage/modules/real_double_vector

Misc
----

.. toctree::
   :maxdepth: 1

   sage/modules/diamond_cutting
   sage/modules/tensor_operations
   sage/modules/finite_submodule_iter
   sage/modules/misc

.. include:: ../footer.txt
